==> estateplat-common-1.2.4-20190703.095229-190-sources.jar: cn/gtmap/estateplat/model/server/core/BdcCxZszmZt.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/*
 * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
 * @version 1.0, 2017/11/29
 * @description 不动产证书证明状态
 */
@Table(name = "bdc_cx_zszm_zt")
public class BdcCxZszmZt implements Serializable {

    /**
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @description 状态Id（主键）
     */
    @Id
    private String ztid;

    /**
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @description 证书编号
     */
    private String zsbh;

    /**
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @description 产权证号
     */
    private String cqzh;

    /**
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @description 不动产类型
     */
    private String bdclx;

    /**
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @description 证书类型
     */
    private String zslx;

    /**
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @description 数据来源
     */
    private String sjly;

    /**
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @description 证书权属状态
     */
    private String zsqszt;

    /**
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @description 现势查封次数
     */
    private Integer xscfcs;

    /**
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @description 现势预查封次数
     */
    private Integer xsycfcs;

    /**
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @description 现势预告次数
     */
    private Integer xsygcs;

    /**
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @description 现势预抵押次数
     */
    private Integer xsydyacs;

    /**
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @description 现势抵押次数
     */
    private Integer xsdyacs;

    /**
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @description 现势异议次数
     */
    private Integer xsyycs;

    /**
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @description 现势地役次数
     */
    private Integer xsdyics;

    /**
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @description 现势锁定次数
     */
    private Integer xssdcs;

    /**
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @description 更新时间
     */
    private Date gxsj;

    public String getZtid() {
        return ztid;
    }

    public void setZtid(String ztid) {
        this.ztid = ztid;
    }

    public String getZsbh() {
        return zsbh;
    }

    public void setZsbh(String zsbh) {
        this.zsbh = zsbh;
    }

    public String getCqzh() {
        return cqzh;
    }

    public void setCqzh(String cqzh) {
        this.cqzh = cqzh;
    }

    public String getBdclx() {
        return bdclx;
    }

    public void setBdclx(String bdclx) {
        this.bdclx = bdclx;
    }

    public String getZslx() {
        return zslx;
    }

    public void setZslx(String zslx) {
        this.zslx = zslx;
    }

    public String getSjly() {
        return sjly;
    }

    public void setSjly(String sjly) {
        this.sjly = sjly;
    }

    public String getZsqszt() {
        return zsqszt;
    }

    public void setZsqszt(String zsqszt) {
        this.zsqszt = zsqszt;
    }

    public Integer getXscfcs() {
        return xscfcs;
    }

    public void setXscfcs(Integer xscfcs) {
        this.xscfcs = xscfcs;
    }

    public Integer getXsycfcs() {
        return xsycfcs;
    }

    public void setXsycfcs(Integer xsycfcs) {
        this.xsycfcs = xsycfcs;
    }

    public Integer getXsygcs() {
        return xsygcs;
    }

    public void setXsygcs(Integer xsygcs) {
        this.xsygcs = xsygcs;
    }

    public Integer getXsydyacs() {
        return xsydyacs;
    }

    public void setXsydyacs(Integer xsydyacs) {
        this.xsydyacs = xsydyacs;
    }

    public Integer getXsdyacs() {
        return xsdyacs;
    }

    public void setXsdyacs(Integer xsdyacs) {
        this.xsdyacs = xsdyacs;
    }

    public Integer getXsyycs() {
        return xsyycs;
    }

    public void setXsyycs(Integer xsyycs) {
        this.xsyycs = xsyycs;
    }

    public Integer getXsdyics() {
        return xsdyics;
    }

    public void setXsdyics(Integer xsdyics) {
        this.xsdyics = xsdyics;
    }

    public Integer getXssdcs() {
        return xssdcs;
    }

    public void setXssdcs(Integer xssdcs) {
        this.xssdcs = xssdcs;
    }

    public Date getGxsj() {
        return gxsj;
    }

    public void setGxsj(Date gxsj) {
        this.gxsj = gxsj;
    }
}

==> estateplat-common-1.2.4-20200729.070208-403-sources.jar: cn/gtmap/estateplat/model/server/core/BdcCxZszmZt.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/*
 * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
 * @version 1.0, 2017/11/29
 * @description 不动产证书证明状态
 */
@Table(name = "bdc_cx_zszm_zt")
public class BdcCxZszmZt implements Serializable {

    /**
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @description 状态Id（主键）
     */
    @Id
    private String ztid;

    /**
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @description 证书编号
     */
    private String zsbh;

    /**
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @description 产权证号
     */
    private String cqzh;

    /**
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @description 不动产类型
     */
    private String bdclx;

    /**
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @description 证书类型
     */
    private String zslx;

    /**
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @description 数据来源
     */
    private String sjly;

    /**
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @description 证书权属状态
     */
    private String zsqszt;

    /**
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @description 现势查封次数
     */
    private Integer xscfcs;

    /**
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @description 现势预查封次数
     */
    private Integer xsycfcs;

    /**
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @description 现势预告次数
     */
    private Integer xsygcs;

    /**
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @description 现势预抵押次数
     */
    private Integer xsydyacs;

    /**
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @description 现势抵押次数
     */
    private Integer xsdyacs;

    /**
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @description 现势异议次数
     */
    private Integer xsyycs;

    /**
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @description 现势地役次数
     */
    private Integer xsdyics;

    /**
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @description 现势锁定次数
     */
    private Integer xssdcs;

    /**
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @description 更新时间
     */
    private Date gxsj;

    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 首次登记状态
     */
    private Integer scdjzt;

    public String getZtid() {
        return ztid;
    }

    public void setZtid(String ztid) {
        this.ztid = ztid;
    }

    public String getZsbh() {
        return zsbh;
    }

    public void setZsbh(String zsbh) {
        this.zsbh = zsbh;
    }

    public String getCqzh() {
        return cqzh;
    }

    public void setCqzh(String cqzh) {
        this.cqzh = cqzh;
    }

    public String getBdclx() {
        return bdclx;
    }

    public void setBdclx(String bdclx) {
        this.bdclx = bdclx;
    }

    public String getZslx() {
        return zslx;
    }

    public void setZslx(String zslx) {
        this.zslx = zslx;
    }

    public String getSjly() {
        return sjly;
    }

    public void setSjly(String sjly) {
        this.sjly = sjly;
    }

    public String getZsqszt() {
        return zsqszt;
    }

    public void setZsqszt(String zsqszt) {
        this.zsqszt = zsqszt;
    }

    public Integer getXscfcs() {
        return xscfcs;
    }

    public void setXscfcs(Integer xscfcs) {
        this.xscfcs = xscfcs;
    }

    public Integer getXsycfcs() {
        return xsycfcs;
    }

    public void setXsycfcs(Integer xsycfcs) {
        this.xsycfcs = xsycfcs;
    }

    public Integer getXsygcs() {
        return xsygcs;
    }

    public void setXsygcs(Integer xsygcs) {
        this.xsygcs = xsygcs;
    }

    public Integer getXsydyacs() {
        return xsydyacs;
    }

    public void setXsydyacs(Integer xsydyacs) {
        this.xsydyacs = xsydyacs;
    }

    public Integer getXsdyacs() {
        return xsdyacs;
    }

    public void setXsdyacs(Integer xsdyacs) {
        this.xsdyacs = xsdyacs;
    }

    public Integer getXsyycs() {
        return xsyycs;
    }

    public void setXsyycs(Integer xsyycs) {
        this.xsyycs = xsyycs;
    }

    public Integer getXsdyics() {
        return xsdyics;
    }

    public void setXsdyics(Integer xsdyics) {
        this.xsdyics = xsdyics;
    }

    public Integer getXssdcs() {
        return xssdcs;
    }

    public void setXssdcs(Integer xssdcs) {
        this.xssdcs = xssdcs;
    }

    public Date getGxsj() {
        return gxsj;
    }

    public void setGxsj(Date gxsj) {
        this.gxsj = gxsj;
    }

    public Integer getScdjzt() {
        return scdjzt;
    }

    public void setScdjzt(Integer scdjzt) {
        this.scdjzt = scdjzt;
    }
}
